/// <reference types="socket.io-client" />
import { BehaviorSubject, Subject } from 'rxjs';
import { AlarmMode, RingDeviceData, RingDeviceType, SocketIoMessage, MessageType, UserLocation, TicketAsset, MessageDataType, AssetSession, LocationEvent } from './ring-types';
import { RingRestClient } from './rest-client';
import { RingCamera } from './ring-camera';
export declare class RingDevice {
    private initialData;
    location: Location;
    assetId: string;
    onData: BehaviorSubject<RingDeviceData>;
    zid: string;
    id: string;
    deviceType: RingDeviceType;
    constructor(initialData: RingDeviceData, location: Location, assetId: string);
    updateData(update: Partial<RingDeviceData>): void;
    readonly data: RingDeviceData;
    readonly name: string;
    readonly supportsVolume: boolean;
    setVolume(volume: number): Promise<void>;
    setInfo(body: any): Promise<void>;
    sendCommand(commandType: string, data?: {}): void;
    toString(): string;
    toJSON(): string;
}
export declare class Location {
    readonly locationDetails: UserLocation;
    readonly cameras: RingCamera[];
    readonly hasHubs: boolean;
    private restClient;
    private seq;
    onMessage: Subject<SocketIoMessage>;
    onDataUpdate: Subject<SocketIoMessage>;
    onDeviceDataUpdate: import("rxjs").Observable<RingDeviceData>;
    onDeviceList: import("rxjs").Observable<SocketIoMessage>;
    onDevices: import("rxjs").Observable<RingDevice[]>;
    onSessionInfo: import("rxjs").Observable<AssetSession[]>;
    onConnected: BehaviorSubject<boolean>;
    reconnecting: boolean;
    connectionPromise?: Promise<SocketIOClient.Socket>;
    securityPanel?: RingDevice;
    assets?: TicketAsset[];
    receivedAssetDeviceLists: string[];
    offlineAssets: string[];
    readonly locationId: string;
    constructor(locationDetails: UserLocation, cameras: RingCamera[], hasHubs: boolean, restClient: RingRestClient);
    createConnection(): Promise<SocketIOClient.Socket>;
    getConnection(): Promise<SocketIOClient.Socket>;
    sendMessage(message: {
        msg: MessageType;
        datatype?: MessageDataType;
        dst: string;
        body?: any;
        seq?: number;
    }): Promise<void>;
    sendCommandToSecurityPanel(commandType: string, data?: {}): Promise<void>;
    setAlarmMode(alarmMode: AlarmMode, bypassSensorZids?: string[]): Promise<void>;
    soundSiren(): Promise<void>;
    silenceSiren(): Promise<void>;
    setLightGroup(groupId: string, on: boolean, durationSeconds?: number): void;
    getNextMessageOfType(type: MessageType, src: string): Promise<any[]>;
    requestList(listType: MessageType, assetId: string): void;
    getList(listType: MessageType, assetId: string): Promise<any[]>;
    getDevices(): RingDevice[] | Promise<RingDevice[]>;
    getRoomList(assetId: string): Promise<any[]>;
    getSecurityPanel(): Promise<RingDevice>;
    disarm(): Promise<void>;
    armHome(bypassSensorZids?: string[]): Promise<void>;
    armAway(bypassSensorZids?: string[]): Promise<void>;
    getEvents(limit?: number, olderThanId?: number | string): Promise<{
        events: LocationEvent[];
        meta: {
            pagination_key: string;
        };
    } & import("./rest-client").ExtendedResponse>;
}
