"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const operators_1 = require("rxjs/operators");
const rxjs_1 = require("rxjs");
class BaseAccessory {
    getService(serviceType, name = this.device.name) {
        if (process.env.RING_DEBUG) {
            name = 'TEST ' + name;
        }
        return (this.accessory.getService(serviceType) ||
            this.accessory.addService(serviceType, name));
    }
    registerCharacteristic(characteristicType, serviceType, getValue, setValue, setValueDebounceTime = 0, name, requestUpdate) {
        const service = this.getService(serviceType, name), characteristic = service.getCharacteristic(characteristicType), { device } = this;
        characteristic.on('get', callback => {
            try {
                const value = getValue(device.data);
                callback(null, value);
                if (requestUpdate) {
                    requestUpdate();
                }
            }
            catch (e) {
                callback(e);
            }
        });
        if (setValue) {
            const onValueToSet = new rxjs_1.Subject();
            characteristic.on('set', (newValue, callback) => __awaiter(this, void 0, void 0, function* () {
                onValueToSet.next(newValue);
                callback();
            }));
            onValueToSet.pipe(operators_1.debounceTime(setValueDebounceTime)).subscribe(setValue);
        }
        ;
        this.device.onData
            .pipe(operators_1.map(getValue), operators_1.distinctUntilChanged())
            .subscribe(value => characteristic.updateValue(value));
    }
    registerLevelCharacteristic(characteristicType, serviceType, getValue, setValue) {
        let targetLevel;
        this.registerCharacteristic(characteristicType, serviceType, data => {
            const newLevel = getValue(data);
            if (newLevel === targetLevel) {
                targetLevel = undefined;
            }
            return targetLevel === undefined ? newLevel : targetLevel;
        }, (volume) => {
            targetLevel = volume;
            setValue(volume);
        }, 500);
    }
    registerObservableCharacteristic(characteristicType, serviceType, onValue, name) {
        const service = this.getService(serviceType, name), characteristic = service.getCharacteristic(characteristicType);
        characteristic.on('get', (callback) => __awaiter(this, void 0, void 0, function* () {
            try {
                const value = yield onValue.pipe(operators_1.take(1)).toPromise();
                callback(null, value);
            }
            catch (e) {
                callback(e);
            }
        }));
        onValue.subscribe(value => {
            characteristic.updateValue(value);
        });
    }
    removeService(service) {
        const existingService = this.accessory.getService(service);
        if (existingService) {
            this.accessory.removeService(existingService);
        }
    }
}
exports.BaseAccessory = BaseAccessory;
