"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const hap_1 = require("./hap");
const base_accessory_1 = require("./base-accessory");
function getBatteryLevel({ batteryLevel, batteryStatus }) {
    if (batteryLevel !== undefined) {
        return batteryLevel;
    }
    else if (batteryStatus === 'full') {
        return 100;
    }
    else if (batteryStatus === 'ok') {
        return 50;
    }
    return 0;
}
function getStatusLowBattery(data) {
    const { StatusLowBattery } = hap_1.hap.Characteristic, batteryLevel = getBatteryLevel(data);
    return batteryLevel > 20
        ? StatusLowBattery.BATTERY_LEVEL_NORMAL
        : StatusLowBattery.BATTERY_LEVEL_LOW;
}
function getBatteryChargingState({ batteryStatus, batteryBackup }) {
    const { ChargingState } = hap_1.hap.Characteristic;
    if (batteryStatus === 'charging' ||
        batteryBackup === 'charged' ||
        batteryBackup === 'charging') {
        return ChargingState.CHARGING;
    }
    return ChargingState.NOT_CHARGEABLE;
}
function hasBatteryStatus({ batteryStatus }) {
    return batteryStatus !== 'none';
}
class BaseDeviceAccessory extends base_accessory_1.BaseAccessory {
    constructor() {
        super();
        setTimeout(() => this.initBase());
    }
    initBase() {
        const { device: { data: initialData }, device } = this, { Characteristic, Service } = hap_1.hap;
        this.registerCharacteristic(Characteristic.Manufacturer, Service.AccessoryInformation, data => data.manufacturerName || 'Ring');
        this.registerCharacteristic(Characteristic.Model, Service.AccessoryInformation, data => data.deviceType);
        this.registerCharacteristic(Characteristic.SerialNumber, Service.AccessoryInformation, data => data.serialNumber || 'Unknown');
        if ('volume' in initialData && 'setVolume' in device) {
            this.registerCharacteristic(Characteristic.Mute, Service.Speaker, () => false);
            this.registerLevelCharacteristic(Characteristic.Volume, Service.Speaker, data => {
                return data.volume ? data.volume * 100 : 0;
            }, (volume) => {
                device.setVolume(volume / 100);
            });
        }
        if (hasBatteryStatus(initialData)) {
            this.registerCharacteristic(Characteristic.BatteryLevel, Service.BatteryService, getBatteryLevel);
            this.registerCharacteristic(Characteristic.StatusLowBattery, Service.BatteryService, getStatusLowBattery);
            this.registerCharacteristic(Characteristic.ChargingState, Service.BatteryService, getBatteryChargingState);
        }
    }
    initSensorService(SensorService) {
        const { Characteristic } = hap_1.hap;
        this.registerCharacteristic(Characteristic.StatusTampered, SensorService, data => {
            return data.tamperStatus === 'ok'
                ? Characteristic.StatusTampered.NOT_TAMPERED
                : Characteristic.StatusTampered.TAMPERED;
        });
        if (hasBatteryStatus(this.device.data)) {
            this.registerCharacteristic(Characteristic.StatusLowBattery, SensorService, data => getStatusLowBattery(data));
        }
    }
}
exports.BaseDeviceAccessory = BaseDeviceAccessory;
