"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("../api");
const hap_1 = require("./hap");
const base_device_accessory_1 = require("./base-device-accessory");
class Beam extends base_device_accessory_1.BaseDeviceAccessory {
    constructor(device, accessory, logger, config) {
        super();
        this.device = device;
        this.accessory = accessory;
        this.logger = logger;
        this.config = config;
        this.isLightGroup = this.device.data.deviceType === api_1.RingDeviceType.BeamsLightGroupSwitch;
        this.groupId = this.device.data.groupId;
        const { Characteristic, Service } = hap_1.hap;
        const { MotionSensor } = Service;
        const { data: { deviceType } } = this.device;
        if (deviceType !== api_1.RingDeviceType.BeamsTransformerSwitch) {
            this.registerCharacteristic(hap_1.hap.Characteristic.MotionDetected, MotionSensor, data => data.motionStatus === 'faulted');
            this.initSensorService(MotionSensor);
        }
        if (deviceType !== api_1.RingDeviceType.BeamsMotionSensor) {
            this.registerCharacteristic(Characteristic.On, Service.Lightbulb, data => Boolean(data.on), value => this.setOnState(value));
        }
        if (deviceType === api_1.RingDeviceType.BeamsSwitch) {
            this.registerLevelCharacteristic(Characteristic.Brightness, Service.Lightbulb, data => (data.level && !isNaN(data.level) ? 100 * data.level : 0), value => this.setLevelState(value));
        }
    }
    setOnState(on) {
        this.logger.info(`Turning ${this.device.name} ${on ? 'On' : 'Off'}`);
        const { beamDurationSeconds } = this.config;
        const duration = beamDurationSeconds
            ? Math.min(beamDurationSeconds, 32767)
            : undefined;
        if (this.isLightGroup && this.groupId) {
            return this.device.location.setLightGroup(this.groupId, on, duration);
        }
        const data = on ? { lightMode: 'on', duration } : { lightMode: 'default' };
        return this.device.sendCommand('light-mode.set', data);
    }
    setLevelState(level) {
        this.logger.info(`Setting brightness of ${this.device.name} to ${level}%`);
        return this.device.setInfo({
            device: { v1: { level: level / 100 } }
        });
    }
}
exports.Beam = Beam;
