"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const hap_1 = require("./hap");
const base_accessory_1 = require("./base-accessory");
const operators_1 = require("rxjs/operators");
const camera_source_1 = require("./camera-source");
class Camera extends base_accessory_1.BaseAccessory {
    constructor(device, accessory, logger, config) {
        super();
        this.device = device;
        this.accessory = accessory;
        this.logger = logger;
        this.config = config;
        const { Characteristic, Service } = hap_1.hap, { StatusLowBattery } = Characteristic, cameraSource = new camera_source_1.CameraSource(device);
        accessory.configureCameraSource(cameraSource);
        if (config.hideCameraMotionSensor) {
            this.removeService(Service.MotionSensor);
        }
        else {
            this.registerObservableCharacteristic(Characteristic.MotionDetected, Service.MotionSensor, device.onMotionDetected);
        }
        if (device.isDoorbot) {
            const onPressed = device.onDoorbellPressed.pipe(operators_1.mapTo(Characteristic.ProgrammableSwitchEvent.SINGLE_PRESS));
            this.registerObservableCharacteristic(Characteristic.ProgrammableSwitchEvent, Service.Doorbell, onPressed);
            if (config.hideDoorbellSwitch) {
                this.removeService(Service.StatelessProgrammableSwitch);
            }
            else {
                this.registerObservableCharacteristic(Characteristic.ProgrammableSwitchEvent, Service.StatelessProgrammableSwitch, onPressed);
            }
        }
        if (device.hasLight) {
            this.registerCharacteristic(Characteristic.On, Service.Lightbulb, data => {
                return data.led_status === 'on';
            }, value => device.setLight(value), 0, undefined, () => device.requestUpdate());
        }
        if (device.hasSiren) {
            this.registerCharacteristic(Characteristic.On, Service.Switch, data => {
                return Boolean(data.siren_status && data.siren_status.seconds_remaining);
            }, value => device.setSiren(value), 0, device.name + ' Siren', () => device.requestUpdate());
        }
        this.registerCharacteristic(Characteristic.Manufacturer, Service.AccessoryInformation, () => 'Ring');
        this.registerCharacteristic(Characteristic.Model, Service.AccessoryInformation, data => `${device.model} (${data.kind})`);
        this.registerCharacteristic(Characteristic.SerialNumber, Service.AccessoryInformation, data => data.device_id);
        if ((device.batteryLevel !== null && device.batteryLevel < 100) ||
            accessory.getService(Service.BatteryService)) {
            this.registerCharacteristic(Characteristic.StatusLowBattery, Service.BatteryService, data => {
                return data.alerts.battery === 'low'
                    ? StatusLowBattery.BATTERY_LEVEL_LOW
                    : StatusLowBattery.BATTERY_LEVEL_NORMAL;
            });
            this.registerObservableCharacteristic(Characteristic.BatteryLevel, Service.BatteryService, device.onBatteryLevel.pipe(operators_1.map(batteryLevel => {
                return batteryLevel === null ? 100 : batteryLevel;
            })));
        }
    }
}
exports.Camera = Camera;
