"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_device_accessory_1 = require("./base-device-accessory");
const hap_1 = require("./hap");
class MultiLevelSwitch extends base_device_accessory_1.BaseDeviceAccessory {
    constructor(device, accessory, logger, config) {
        super();
        this.device = device;
        this.accessory = accessory;
        this.logger = logger;
        this.config = config;
        const { Characteristic, Service } = hap_1.hap;
        const { data: initialData } = this.device;
        this.registerCharacteristic(Characteristic.On, Service.Lightbulb, data => Boolean(data.on), value => this.setOnState(value));
        if (initialData.level !== undefined) {
            this.registerLevelCharacteristic(Characteristic.Brightness, Service.Lightbulb, data => (data.level && !isNaN(data.level) ? 100 * data.level : 0), value => this.setLevelState(value));
        }
        // TODO: Hue/Sat/Color Temp
    }
    setOnState(on) {
        this.logger.info(`Turning ${this.device.name} ${on ? 'On' : 'Off'}`);
        return this.device.setInfo({ device: { v1: { on } } });
    }
    setLevelState(level) {
        this.logger.info(`Setting brightness of ${this.device.name} to ${level}%`);
        return this.device.setInfo({
            device: { v1: { level: level / 100 } }
        });
    }
}
exports.MultiLevelSwitch = MultiLevelSwitch;
