"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_device_accessory_1 = require("./base-device-accessory");
const operators_1 = require("rxjs/operators");
const hap_1 = require("./hap");
class SecurityPanel extends base_device_accessory_1.BaseDeviceAccessory {
    constructor(device, accessory, logger, config) {
        super();
        this.device = device;
        this.accessory = accessory;
        this.logger = logger;
        this.config = config;
        this.alarmStates = this.config.alarmOnEntryDelay
            ? ['entry-delay', 'burglar-alarm']
            : ['burglar-alarm'];
        const { Characteristic, Service } = hap_1.hap;
        this.device.onData
            .pipe(operators_1.distinctUntilChanged((a, b) => a.mode === b.mode))
            .subscribe(data => {
            this.targetState = this.getTargetState(data);
        });
        this.registerCharacteristic(Characteristic.SecuritySystemCurrentState, Service.SecuritySystem, data => {
            const state = this.getCurrentState(data);
            if (state === this.targetState) {
                this.targetState = undefined;
            }
            return state;
        });
        this.registerCharacteristic(Characteristic.SecuritySystemTargetState, Service.SecuritySystem, data => this.getTargetState(data), value => this.setTargetState(value));
        if (config.hideAlarmSirenSwitch) {
            this.removeService(Service.Switch);
        }
        else {
            this.registerCharacteristic(Characteristic.On, Service.Switch, data => data.siren && data.siren.state === 'on', value => {
                if (value) {
                    return this.device.location.soundSiren();
                }
                return this.device.location.silenceSiren();
            }, 0, this.device.name + ' Siren');
        }
    }
    getCurrentState({ mode, alarmInfo }) {
        const { Characteristic: { SecuritySystemCurrentState: State } } = hap_1.hap;
        if (alarmInfo && this.alarmStates.includes(alarmInfo.state)) {
            return State.ALARM_TRIGGERED;
        }
        switch (mode) {
            case 'all':
                return State.AWAY_ARM;
            case 'some':
                return State.STAY_ARM;
            case 'none':
                return State.DISARMED;
            default:
                return State.DISARMED;
        }
    }
    setTargetState(state) {
        const { Characteristic: { SecuritySystemTargetState: State } } = hap_1.hap, { location, data } = this.device;
        if (state === State.NIGHT_ARM) {
            state = State.STAY_ARM;
            // Ring doesn't have night mode, so switch over to stay mode
            setTimeout(() => {
                this.getService(hap_1.hap.Service.SecuritySystem)
                    .getCharacteristic(hap_1.hap.Characteristic.SecuritySystemTargetState)
                    .updateValue(state);
            }, 100);
        }
        if (state === this.getCurrentState(data)) {
            this.targetState = undefined;
            return;
        }
        this.targetState = state;
        if (state === State.AWAY_ARM) {
            this.logger.info(`Arming (Away) ${this.device.name}`);
            location.armAway();
        }
        else if (state === State.DISARM) {
            this.logger.info(`Disarming ${this.device.name}`);
            location.disarm();
        }
        else {
            this.logger.info(`Arming (Home) ${this.device.name}`);
            location.armHome();
        }
    }
    getTargetState(data) {
        return this.targetState || this.getCurrentState(data);
    }
}
exports.SecurityPanel = SecurityPanel;
